import { useState } from 'react';
import { useGame } from '../context/GameContext';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faMusic, faPlus, faDoorOpen } from '@fortawesome/free-solid-svg-icons';

const HomeScreen = () => {
  const { createLobby, joinLobby } = useGame();
  const [playerName, setPlayerName] = useState('');
  const [lobbyId, setLobbyId] = useState('');
  const [isCreateMode, setIsCreateMode] = useState(true);

  const handleSubmit = (e) => {
    e.preventDefault();
    
    if (!playerName.trim()) {
      return;
    }
    
    if (isCreateMode) {
      createLobby(playerName.trim());
    } else {
      if (!lobbyId.trim()) {
        return;
      }
      joinLobby(lobbyId.trim().toUpperCase(), playerName.trim());
    }
  };

  return (
    <div className="home-screen">
      <div className="logo">
        <img src="/logo.png" alt="Song Battle Logo" className="logo-image" />
        <h1>Liedkampf</h1>
      </div>
      
      <div className="card">
        <div className="tabs">
          <button 
            className={isCreateMode ? 'active' : ''}
            onClick={() => setIsCreateMode(true)}
          >
            <FontAwesomeIcon icon={faPlus} /> Erstellen
          </button>
          <button 
            className={!isCreateMode ? 'active' : ''}
            onClick={() => setIsCreateMode(false)}
          >
            <FontAwesomeIcon icon={faDoorOpen} /> Beitreten
          </button>
        </div>
        
        <form onSubmit={handleSubmit}>
          <div className="form-group">
            <label htmlFor="player-name">Dein Name</label>
            <input
              type="text"
              id="player-name"
              value={playerName}
              onChange={(e) => setPlayerName(e.target.value)}
              placeholder="Gib deinen Namen ein"
              maxLength={20}
              required
            />
          </div>
          
          {!isCreateMode && (
            <div className="form-group">
              <label htmlFor="lobby-id">Spielcode</label>
              <input
                type="text"
                id="lobby-id"
                value={lobbyId}
                onChange={(e) => setLobbyId(e.target.value.toUpperCase())}
                placeholder="6-stelligen Code eingeben"
                maxLength={6}
                required
              />
            </div>
          )}
          
          <button type="submit" className="btn primary pixelated full-width">
            {isCreateMode ? 'Neues Spiel erstellen' : 'Spiel beitreten'}
            <span className="pixel-corner tl"></span>
            <span className="pixel-corner tr"></span>
            <span className="pixel-corner bl"></span>
            <span className="pixel-corner br"></span>
          </button>
        </form>
      </div>
      
      <footer className="home-footer">
        <p>ik wes doch och nüsch</p>
      </footer>
    </div>
  );
};

// Make sure default export is explicit
export default HomeScreen;
